@@ -3,8 +3,11 @@ from .mypygame import Mypygame
 from .myserial import Myserial
 from .myservo import Servo
 from .mysound import Sound
+import froxiaofeidriver.myvideo
+from .mygesture import Guester
 from .myrecognizeLBP import RecognizeLBP
 from .myfacecollect import Facecollect
 from .mycolor import Color
 from .mytts import Pyttsx
-from .mygesture import Guester
\ No newline at end of file
+from .mytrafficsign import TrafficSign
+from .myQRcode import QRcode
